littlemcmc.step\_sizes.DualAverageAdaptation
============================================

.. currentmodule:: littlemcmc.step_sizes

.. autoclass:: DualAverageAdaptation

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DualAverageAdaptation.__init__
      ~DualAverageAdaptation.current
      ~DualAverageAdaptation.reset
      ~DualAverageAdaptation.stats
      ~DualAverageAdaptation.update
      ~DualAverageAdaptation.warnings
   
   

   
   
   